@@ -2,7 +2,7 @@
   RFver <- read.dcf(file=system.file("DESCRIPTION", package=pkgname),
                     fields="Version")
   packageStartupMessage(paste(pkgname, RFver))
-  packageStartupMessage("Heart and Lung Institute, Imperial College London &\nScientific Computing Group, Sentrana Inc.")
+  packageStartupMessage("School of Public Health, Imperial College London &\nScientific Computing Group, Sentrana Inc.")
 }
 
 #.onLoad <- function(libname, pkgname) {
